<?php
// $Id: facebook_xoops_service.class.php,v 1.8 2011/04/30 19:32:45 ohwada Exp $

//================================================================
// Facebook Module
// 2011-03-01 K.OHWADA
//================================================================

//---------------------------------------------------------
// change log
// 2011-04-30 K.OHWADA
// set_user_param()
//---------------------------------------------------------

if ( !defined('_FACEBOOK_LOADED') ) {

	define('_FACEBOOK_LOADED', '1' );
	define('FACEBOOK_DIR', XOOPS_ROOT_PATH. '/modules/facebook' );

	include_once FACEBOOK_DIR.'/class/config.class.php';

	$facebook_class =& facebook_config::getInstance();
	$facebook_path  =  $facebook_class->get_pear_path();

	set_include_path( get_include_path() . PATH_SEPARATOR . $facebook_path );

	require_once 'HTTP/Request2.php';
	require_once 'Cache/Lite.php';
	require_once FACEBOOK_DIR.'/class/service.class.php';
	require_once FACEBOOK_DIR.'/class/exauth_base.class.php';
	require_once FACEBOOK_DIR.'/class/exauth.class.php';
}

//================================================================
// class facebook_xoops_service
//================================================================
class facebook_xoops_service
{
	var $_service = null;
	var $_exauth  = null;
	var $_config  = null;

	var $_scope_read_stream    = false;
	var $_scope_publish_stream = false;
	var $_scope_offline_access = false;

	var $_error_code = 0;
	var $_error_msg  = null;

	var $_EXAUTH_TYPE = 'facebook';

//---------------------------------------------------------
// constructor
//---------------------------------------------------------
function facebook_xoops_service()
{
	$this->_service =& facebook_service::getInstance();
	$this->_exauth  =& facebook_exauth::getInstance();
	$this->_config  =& facebook_config::getInstance();
}

function &getInstance()
{
	static $instance;
	if (!isset($instance))  {
		$instance =& new facebook_xoops_service();
	}
	return $instance;
}

function &get_exauth_Instance()
{
	return $this->_exauth;
}

function get_error_code() 
{
	return $this->_error_code ;
}

function get_error_msg() 
{
	return $this->_error_msg ;
}

//---------------------------------------------------------
// Initialization
//---------------------------------------------------------
function init()
{
	$path = $this->_config->get_cache_path();

	$id     = '';
	$secret = '';

	$config = $this->_config->get_config();
	if ( is_array($config) ) {
		$id     = $config['app_id'];
		$secret = $config['app_secret'];
		$this->_scope_read_stream    = $config['scope_read_stream'];
		$this->_scope_publish_stream = $config['scope_publish_stream'];
		$this->_scope_offline_access = $config['scope_offline_access'];
	}

	if( empty($id) || empty($secret) ) {
		return false;
	}

	$this->_service->set_app_id(     $id );
	$this->_service->set_app_secret( $secret );

	$this->_service->set_scope_read_stream(    $this->_scope_read_stream );
	$this->_service->set_scope_publish_stream( $this->_scope_publish_stream );
	$this->_service->set_scope_offline_access( $this->_scope_offline_access );

	$this->_service->set_cache_use( true );
	$this->_service->set_cache_dir( $path );

	$this->_service->set_convert_space_use( true );

	return true;
}

function get_scope_read_stream() 
{
	return $this->_scope_read_stream ;
}

function get_scope_publish_stream() 
{
	return $this->_scope_publish_stream ;
}

function get_scope_offline_access() 
{
	return $this->_scope_offline_access ;
}

//---------------------------------------------------------
// Redirect to Facebook server
//---------------------------------------------------------
function login( $num_callback )
{
	$url_callback = $this->get_callback_url( $num_callback );
	$this->_service->set_url_callback( $url_callback );

	$ret = $this->_service->login();
	if ( !$ret ) {
		$this->_error_code = $this->_service->get_error_code();
		$this->_error_msg  = $this->_service->get_error_msg();
        return false;
	}
	return true;
}

function get_callback_url( $num ) 
{
	if (( $num == 1 )||( $num == 2 )) {
		return XOOPS_URL . '/modules/facebook/callback'.$num.'.php';
	}
	return false;
}

//---------------------------------------------------------
// get Facebook ID
//---------------------------------------------------------
function callback( $num_callback )
{
	$url_callback = $this->get_callback_url( $num_callback );
	$this->_service->set_url_callback( $url_callback );

	$param = $this->_service->callback();
	if ( !is_array($param) ) {
		$this->_error_code = $this->_service->get_error_code();
		$this->_error_msg  = $this->_service->get_error_msg();
        return false;
	}

	$token = $param['access_token'];
	$this->_service->set_token(         $token );
	$this->_service->set_session_token( $token );

	$user = $this->get_user_me();
	if ( !is_array($user) ) {
        return false;
	}

	$param['user_id'] = $user['id'];
	return $param;
}

//---------------------------------------------------------
// set user param
//---------------------------------------------------------
function set_user_param( $user_id ) 
{
	$token = $this->get_user_token( $user_id );
	if( empty($token) ) {
		return false;
	}

	$this->_service->set_token( $token );
	return true;
}

function get_user_token( $uid )
{
	$token = null;

	if ( $this->_scope_offline_access ) {
		$id = $this->_exauth->get_exauth_id( $uid );
		if ( empty($id) ) {
			$this->_error_code = -1;
			$this->_error_msg  = _FACEBOOK_ERR_FACEBOOK_ID;
			return false;	// NOT set ID
		}
		$token = $this->_exauth->get_user_token( $uid );

	} else {
		$token = $this->_service->get_session_token();
	}

	if( empty($token) ) {
		$this->_error_code = -2;
		$this->_error_msg  = _FACEBOOK_ERR_TOKEN;
		return false;
	}

	return $token;
}

//---------------------------------------------------------
// get user me
//---------------------------------------------------------
function get_user_me()
{
	$user = $this->_service->get_me();
	if ( !is_array($user) ) {
		$this->_error_code = $this->_service->get_error_code();
		$this->_error_msg  = $this->_service->get_error_msg();
       	return false;
	}
	$user = $this->_service->convert_encoding_user( $user, _CHARSET );
	return $user;
}

//---------------------------------------------------------
// get news feeds
//---------------------------------------------------------
function set_elapse_words( $w1, $w2, $w3 ) 
{
	$this->_service->set_elapse_full( 
		$this->convert_to_utf8( $w1 ) );
	$this->_service->set_elapse_hour( 
		$this->convert_to_utf8( $w2 ) ) ;
	$this->_service->set_elapse_min(
		$this->convert_to_utf8( $w3 ) );
}

function get_me_feeds()
{
	$feeds = $this->_service->get_me_feeds( true );
	if ( !$feeds ) {
		$this->_error_code = $this->_service->get_error_code();
		$this->_error_msg  = $this->_service->get_error_msg();
        return false;
	}

	$feeds = $this->_service->feeds_to_array( $feeds );
	$feeds = $this->_service->convert_feeds(  $feeds );
	$feeds = $this->_service->convert_encoding_feeds( $feeds, _CHARSET );
	return $feeds;
}

//---------------------------------------------------------
// post
//---------------------------------------------------------
function post( $msg )
{
	$msg = $this->convert_to_utf8( $msg );
	$ret = $this->_service->post_me_feed( $msg );
	if ( !$ret ) {
		$this->_error_code = $this->_service->get_error_code();
		$this->_error_msg  = $this->_service->get_error_msg();
        return false;
	}
	return true;
}

function get_post_error( $code, $msg )
{
	switch ($code)
	{
		case 61:
			$error = _FACEBOOK_ERR_POST_EMPTY;
			break;

		case 62:
			$error  = _FACEBOOK_ERR_POST_FAIL.'<br />';
			$error .= $msg;
			break;

		default:
			$error = _FACEBOOK_ERR_SOMETHING;
			break;
	}
	return $error;
}

function convert_to_utf8( $str ) 
{
	return $this->_service->convert_to_utf8( $str, _CHARSET ); 
}

// === class end ===

}

?>